@@ -1,5 +1,15 @@
 package TAP::Parser::SourceHandler::Feature;
-$TAP::Parser::SourceHandler::Feature::VERSION = '0.67';
+$TAP::Parser::SourceHandler::Feature::VERSION = '0.75';
+=head1 NAME
+
+TAP::Parser::SourceHandler::Feature - Test::BDD::Cucumber's prove integration
+
+=head1 VERSION
+
+version 0.75
+
+=cut
+
 use strict;
 use warnings;
 
@@ -38,11 +48,22 @@ sub can_handle {
             my %options = %{ $source->config_for($class) };
             while ( my ( $key, $value ) = each %options ) {
 
-                # Nasty hack
-                if ( length $key > 1 ) {
-                    push( @cmd_line, "--$key", $value );
-                } else {
-                    push( @cmd_line, "-$key", $value );
+                # --feature-option 'tags=@something'
+                # --feature-option 'tags=@somethingelse'
+                #
+                # is passed in %options as:
+                # { ..., tags => [ '@something', '@somethingelse' ], ... }
+                #
+                # Now unfold that back into an argument array as
+                #  --tags @something --tags @somethingelse
+                $value = [ $value ] unless ref $value;
+                for my $v (@$value) {
+                    # Nasty hack
+                    if ( length $key > 1 ) {
+                        push( @cmd_line, "--$key", $v );
+                    } else {
+                        push( @cmd_line, "-$key", $v );
+                    }
                 }
             }
 
@@ -104,6 +125,8 @@ sub make_iterator {
     $context->release;
 
     close $output_fh;
+    $pherkin->_post_run;
+
     exit;
 }
 
