@@ -1,12 +1,12 @@
 package Test::BDD::Cucumber::Parser;
-$Test::BDD::Cucumber::Parser::VERSION = '0.67';
+$Test::BDD::Cucumber::Parser::VERSION = '0.75';
 =head1 NAME
 
 Test::BDD::Cucumber::Parser - Parse Feature files
 
 =head1 VERSION
 
-version 0.67
+version 0.75
 
 =head1 DESCRIPTION
 
@@ -58,19 +58,21 @@ sub parse_string {
 
 sub parse_file {
     my ( $class, $string ) = @_;
+    my $content;
     {
         local $/;
         open(my $in, '<', $string) or die $?;
         binmode $in, 'utf8';
-        return $class->_construct(
-            Test::BDD::Cucumber::Model::Document->new(
-                {
-                    content => <$in>,
-                    filename => '' . $string
-                }
-            )
-        );
+        $content = <$in>;
+        close $in or warn $?;
     }
+    return $class->_construct(
+        Test::BDD::Cucumber::Model::Document->new(
+            {
+                content => $content,
+                filename => '' . $string
+            })
+        );
 }
 
 sub _construct {
@@ -162,7 +164,9 @@ sub _extract_language {
     my ( $self, $lines ) = @_;
 
 # return default language if we don't see the language directive on the first line
-    return 'en' unless $lines->[0]->raw_content =~ m{^\s*#\s*language:\s+(.+)$};
+    return 'en'
+        unless ($lines and @$lines
+                and $lines->[0]->raw_content =~ m{^\s*#\s*language:\s+(.+)$});
 
     # remove the language directive if we saw it ...
     shift @$lines;
@@ -238,7 +242,7 @@ sub _finish_scenario {
     if ( @{ $feature->scenarios } ) {
         my $last_scenario = $feature->scenarios->[-1];
         if ( $last_scenario->keyword_original =~ m/^($self->{langdef}->{scenarioOutline})/
-             && !@{ $last_scenario->data } )
+             && !@{ $last_scenario->datasets } )
         {
             die parse_error_from_line(
                 "Outline scenario expects 'Examples:' section",
@@ -272,19 +276,22 @@ sub _extract_scenarios {
                 line => $line,
                 );
             @tags = ();
+            @lines = $self->_extract_examples_description( $dataset, @lines );
+            @lines = $self->_extract_table( 6, $dataset,
+                                            $self->_remove_next_blanks(@lines) );
+
             if (@{$feature->scenarios->[-1]->datasets}) {
                 my $prev_ds = $feature->scenarios->[-1]->datasets->[0];
-                my $prev_ds_cols = join '|', keys %{$prev_ds->data->[0]};
-                my $cur_ds_cols = join '|', keys %{$dataset->data->[0]};
+                my $prev_ds_cols = join '|', sort keys %{$prev_ds->data->[0]};
+                my $cur_ds_cols = join '|', sort keys %{$dataset->data->[0]};
                 die parse_error_from_line(
-                    q{'Examples:' not in line with previous 'Examples:'}, $line )
+                    q{Columns of 'Examples:' not in line with }
+                    . q{previous 'Examples:' }
+                    . qq{('$prev_ds_cols' vs '$cur_ds_cols')}, $line )
                     if $prev_ds_cols ne $cur_ds_cols;
             }
             push @{$feature->scenarios->[-1]->datasets}, $dataset;
 
-            @lines = $self->_extract_examples_description( $dataset, @lines );
-            @lines = $self->_extract_table( 6, $dataset,
-                                            $self->_remove_next_blanks(@lines) );
         }
         elsif ( ( $type, $name ) =
                 $self->_is_scenario_line( $line->content ) ) {
@@ -357,10 +364,11 @@ sub _extract_steps {
             next;
         }
 
-        if ($last_line_was_comment) {
+        if ($last_line_was_comment and not $warned_mixed_comments) {
             # don't issue this warning if the comment is after
-            warn 'Mixing comments and steps is deprecated: not allowed in Gherkin'
-                unless $warned_mixed_comments;
+            warn parse_error_from_line(
+                'Mixing comments and steps is not allowed in Gherkin',
+                $line);
             $warned_mixed_comments = 1;
         }
 
@@ -527,6 +535,7 @@ Peter Sergeant C<pete@clueball.com>
 
 =head1 LICENSE
 
-Copyright 2011-2016, Peter Sergeant; Licensed under the same terms as Perl
+  Copyright 2019-2020, Erik Huelsmann
+  Copyright 2011-2019, Peter Sergeant; Licensed under the same terms as Perl
 
 =cut
